package simpleJPA.model;



import java.sql.*;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;

/**
 * 
 * The DB_Accessor class contains methods to access, update, and query tables int the 
 * database.  Important database parameters are specified in /META-INF/persistence.xml.
 * 
 * 
 */

public class DB_Accessor {

	private EntityManagerFactory emf;	
	private EntityManager em;
	
	public DB_Accessor(){	
		 emf = Persistence.createEntityManagerFactory("simplejpa", System.getProperties());	
		 em = emf.createEntityManager();
	}

	//This method only exists because it was needed when using plain JDBC.  It is called from
	//a Controller class, and one benefit this lab illustrates is that the View and Controller
	//classes do not need to change.
	public void insertClient(Client client){
		  doInsert(client);
		}

	public Client [] getClients(){		
		    String query = "SELECT c FROM Client c";
		    Query q = em.createQuery(query);
		    List list = q.getResultList();
		    Client [] cArr = (Client[]) list.toArray(new Client[0]);
		    return cArr;	  
	  }
	  
	
	public void updateClientEmployee(Client client){
	    em.getTransaction().begin();
		    Client cX = em.find(Client.class, client.getID_int());
		    Employee p = client.getEmployee();
		    cX.getEmployee().setEmployeeName(p.getEmployeeName());
		    cX.getEmployee().setPosition(p.getPosition());
	    em.getTransaction().commit();

	}
	
	public void updateClientEmployees(Client client){
	    em.getTransaction().begin();
		    Client cX = em.find(Client.class, client.getID_int());

			Set<Employee> pSet= client.getEmployees();
			Object [] pArr =  pSet.toArray();
			int numParts = pArr.length;
			Employee p;
			for(int j=0; j<numParts; j++){
				p=(Employee) pArr[j];				
				cX.getEmployees().add((Employee) pArr[j]);
			}

	    em.getTransaction().commit();

	}

 
public void doInsert(Object newObject){
	em.getTransaction().begin();
	em.persist(newObject);
	em.getTransaction().commit();

 }


public void close(){
	em.close();
	emf.close();
}

//This method was used for quick testing.  If you add or modify this class, remove the comments
//below to test your changes.  Remember to add the -javaagent argument.
 public static void main(String [] args){
 
  /*	 
   DB_Accessor dba=new DB_Accessor();
   
   Client [] clients= dba.getClients();
 
   for (int i=0; i<clients.length; i++) {
       System.out.println("name: "+clients[i].getName()+ ", industry: "+ clients[i].getIndustry());
   }
   
   int size = 3;
   Client client;

   for(int i=12; i<size+12; i++){
     client = new Client();
     String[] item = {"name","ind","hqtr"};  			   
     client.setName(item[0]+i);
     client.setIndustry(item[1]+i);
     client.setHeadquarterLocation(item[2]+i);
     
   Employee p;
   for(int j=0; j<4; j++){
    	 p=new Employee();
    	 p.setEmployeeName("Phil"+i+j);
    	 p.setPosition("dev"+i+j);

    	 //this is for multi
    	 client.addParticipant(p);

    	 //this is for single task
    	 //client.setParticipant(p);
    	 
    	
     }
   
     dba.doInsert(client);
  
     
     System.out.println("**DBA - created client #:"+i);	
	
   }//end for i	  
   
   dba.close();
  */ 
   
 }//end main

}//end class